@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Wuhan Deepin Technology Co., Ltd.
- *
- * Author:     Iceyer <me@iceyer.net>
- *
- * Maintainer: Iceyer <me@iceyer.net>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #include "progressview.h"
 #include "widgetutil.h"
@@ -48,33 +31,20 @@ ProgressView::ProgressView(DWidget *parent) : DWidget(parent)
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setContentsMargins(0, 1, 0, 0);
 
-//    int lcdFontId = QFontDatabase::addApplicationFont(":/theme/SourceHanSansSC-Medium.ttf");
-//    int lcdFontId1 = QFontDatabase::addApplicationFont(":/theme/SourceHanSansSC-Bold.ttf");
-//    QStringList m_fontList;
-//    m_fontList.clear();
-//    if (lcdFontId != -1) {
-//        m_fontList << QFontDatabase::applicationFontFamilies(lcdFontId);
-//    }
-//    if (lcdFontId != -1) {
-//        m_fontList << QFontDatabase::applicationFontFamilies(lcdFontId1);
-//    }
-
     DLabel *m_title = new DLabel(tr("Burning"));
+    m_title->setAccessibleName("progressWidget_title");
     DPalette pa = DApplicationHelper::instance()->palette(m_title);
     QBrush brush = DApplicationHelper::instance()->palette(m_title).text();
     pa.setBrush(DPalette::Text, brush);
     m_title->setPalette(pa);
     DFontSizeManager::instance()->bind(m_title, DFontSizeManager::T3);
-//    QFont qf = m_title->font();
-//    if (m_fontList.size() > 0)
-//        qf.setFamily(m_fontList.at(0));
-//    qf.setPixelSize(24);
-//    m_title->setFont(qf);
 
     m_waterProgress = new Dtk::Widget::DWaterProgress;
+    m_waterProgress->setAccessibleName("progressWidget_waterProgress");
     m_waterProgress->setFixedSize(100, 100);
 
     DLabel *m_hitsTitle = new DLabel(tr("Burning, please wait..."));
+    m_hitsTitle->setAccessibleName("progressWidget_hitsTitleLabel");
     m_hitsTitle->setObjectName("ProgressHitsTitle");
     DFontSizeManager::instance()->bind(m_hitsTitle, DFontSizeManager::T5);
     m_hitsTitle->setAlignment(Qt::AlignCenter);
@@ -82,29 +52,20 @@ ProgressView::ProgressView(DWidget *parent) : DWidget(parent)
     m_hitsTitle->setContentsMargins(20, 0, 20, 0);
 
     DTipLabel *m_hits = new DTipLabel(tr("Do not remove the disk or shut down the computer during the process"));
-//    DLabel *m_hits = new DLabel(tr("Do not remove the disk or shut down the computer during the process"));
+    m_hits->setAccessibleName("progressWidget_hitsTipLabel");
     m_hits->setObjectName("ProgressHits");
-//    m_hits->setFixedSize(213, 17);
     m_hits->setWordWrap(true);
     m_hits->setAlignment(Qt::AlignCenter);
     m_hits->setContentsMargins(20, 0, 20, 0);
     DFontSizeManager::instance()->bind(m_hits, DFontSizeManager::T8);
-//    QFont qf = m_hits->font();
-////    qf.setPixelSize(12);
-//    qf.setLetterSpacing(QFont::AbsoluteSpacing, 2);
-//    m_hits->setFont(qf);
     m_hits->setAlignment(Qt::AlignHCenter | Qt::AlignTop);
-//    DPalette pa = DApplicationHelper::instance()->palette(m_hits);
-//    QBrush brush = DApplicationHelper::instance()->palette(m_hits).textTips();
-//    pa.setBrush(DPalette::WindowText, brush);
-//    m_hits->setPalette(pa);
 
-//    SuggestButton *start = new SuggestButton();
     DPushButton *start = new DPushButton();
     start->setFocusPolicy(Qt::NoFocus);
+    start->setAccessibleName("progressWidget_cancelButton");
     start->setFixedSize(310, 36);
     start->setObjectName("ProgressCancel");
-    start->setText(tr("Cancel"));
+    start->setText(tr("Cancel", "button"));
     DFontSizeManager::instance()->bind(start, DFontSizeManager::T6);
 
     mainLayout->addWidget(m_title, 0, Qt::AlignHCenter);
@@ -119,10 +80,6 @@ ProgressView::ProgressView(DWidget *parent) : DWidget(parent)
     m_waterProgress->setValue(0);
     m_waterProgress->start();
 
-//    this->setStyleSheet(WidgetUtil::getQss(":/theme/light/ProgressView.theme"));
-//    this->setStyleSheet("#ProgressHits{line-height: 1.67;}");
-
-//    connect(start, &SuggestButton::clicked, this, &ProgressView::testCancel);
     start->hide();
 
 
@@ -135,9 +92,7 @@ ProgressView::ProgressView(DWidget *parent) : DWidget(parent)
             pa = palette();
             pa.setColor(DPalette::Background, QColor(255, 255, 255));
             setPalette(pa);
-//            pa = m_title->palette();
-//            pa.setColor(DPalette::WindowText, QColor("#414D68"));
-//            m_title->setPalette(pa);
+
             pa = m_hitsTitle->palette();
             pa.setColor(DPalette::WindowText, QColor("#001A2E"));
             m_hitsTitle->setPalette(pa);
