@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Uniontech Software Co., Ltd.
- *
- * Author:     shenfusheng <shenfusheng@uniontech.com>
- *
- * Maintainer: shenfusheng <shenfusheng@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
 
 #include "qtinstallerfactory.h"
 
@@ -29,6 +12,8 @@
 #include "qtarminstaller.h"
 #elif defined(__sw_64__)
 #include "qtswinstaller.h"
+#else
+#include "qtotherinstaller.h"
 #endif
 
 #include <QDebug>
@@ -50,7 +35,7 @@ QtBaseInstaller* QtInstallerFactory::createInstaller()
 
 #if defined(Q_PROCESSOR_X86)
     qDebug() << "Architecture:X86_64";
-    pInstaller = new QtX86Installer;
+    pInstaller = new QtX86Installer();
 #elif defined(Q_PROCESSOR_MIPS)
     qDebug() << "Architecture:MIPS";
     pInstaller = new QtMipsInstaller;
@@ -61,7 +46,8 @@ QtBaseInstaller* QtInstallerFactory::createInstaller()
     qDebug() << "Architecture:SW";
     pInstaller = new QtSwInstaller;
 #else
-#error "not support architecture"
+    qDebug() << "Architecture:Other";
+    pInstaller = new QtOtherInstaller;
 #endif
 
     return pInstaller;
