@@ -1,8 +1,13 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-only
+
 #ifndef IMAGECHECKOBJ_H
 #define IMAGECHECKOBJ_H
 
 #include <gtest/gtest.h>
-#include <backend/bootmaker.h>
+#include "backend/bootmaker.h"
+#include "util/utils.h"
 
 class ImageCheckObj : public ::testing::Test
 {
