@@ -48,38 +48,38 @@
 <context>
     <name>ISOSelectView</name>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="126"/>
+        <location filename="../app/view/isoselectview.cpp" line="116"/>
         <source>Drag an ISO image file here</source>
         <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་འདིར་འཇོག་རྒྱུ།</translation>
     </message>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="145"/>
+        <location filename="../app/view/isoselectview.cpp" line="125"/>
         <source>OR</source>
         <translation>ཡང་ན།</translation>
     </message>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="89"/>
-        <location filename="../app/view/isoselectview.cpp" line="163"/>
+        <location filename="../app/view/isoselectview.cpp" line="82"/>
+        <location filename="../app/view/isoselectview.cpp" line="140"/>
         <source>Select an ISO image file</source>
         <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་འདེམས་རྒྱུ།</translation>
     </message>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="211"/>
+        <location filename="../app/view/isoselectview.cpp" line="170"/>
         <source>Next</source>
         <translation>རྗེས་མ། </translation>
     </message>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="297"/>
+        <location filename="../app/view/isoselectview.cpp" line="225"/>
         <source>Reselect an ISO image file</source>
         <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་ཡང་བསྐྱར་འདེམས་རྒྱུ།</translation>
     </message>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="234"/>
+        <location filename="../app/view/isoselectview.cpp" line="188"/>
         <source>Illegal ISO image file</source>
         <translation>ཁྲིམས་འགལ་ISOཡིག་ཆ།</translation>
     </message>
     <message>
-        <location filename="../app/view/isoselectview.cpp" line="438"/>
+        <location filename="../app/view/isoselectview.cpp" line="328"/>
         <source>Detecting ISO file, please wait...</source>
         <translation>ISOཡིག་ཆ་བཤེར་འཇལ་བྱེད་བཞིན་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
     </message>
@@ -87,23 +87,24 @@
 <context>
     <name>ProgressView</name>
     <message>
-        <location filename="../app/view/progressview.cpp" line="62"/>
+        <location filename="../app/view/progressview.cpp" line="51"/>
         <source>Burning</source>
         <translation>བཟོ་བཞིན་པ།</translation>
     </message>
     <message>
-        <location filename="../app/view/progressview.cpp" line="78"/>
+        <location filename="../app/view/progressview.cpp" line="63"/>
         <source>Burning, please wait...</source>
         <translation>བཟོ་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
     </message>
     <message>
-        <location filename="../app/view/progressview.cpp" line="90"/>
+        <location filename="../app/view/progressview.cpp" line="71"/>
         <source>Do not remove the disk or shut down the computer during the process</source>
         <translation>བཟོ་བའི་སྐབས་སུ་སྡུད་སྡེར་སྤོ་འབུད་དང་རྩིས་འཁོར་གློག་གསོད་བྱ་མི་རུང་།</translation>
     </message>
     <message>
-        <location filename="../app/view/progressview.cpp" line="112"/>
+        <location filename="../app/view/progressview.cpp" line="85"/>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>ཕྱིར་འཐེན།</translation>
     </message>
 </context>
@@ -115,13 +116,13 @@
         <translation>སྤོ་རུང་སྡུད་སྡེར།</translation>
     </message>
     <message>
-        <location filename="../libdbm/util/utils.cpp" line="223"/>
-        <location filename="../libdbm/util/utils.cpp" line="369"/>
+        <location filename="../libdbm/util/utils.cpp" line="224"/>
+        <location filename="../libdbm/util/utils.cpp" line="370"/>
         <source>Removable disk</source>
         <translation>སྤོ་རུང་སྡུད་སྡེར།</translation>
     </message>
     <message>
-        <location filename="../app/main.cpp" line="118"/>
+        <location filename="../app/main.cpp" line="122"/>
         <source>Boot Maker</source>
         <translation>འགོ་སློང་སྡེར་བཟོ་བའི་ཡོ་བྱད།</translation>
     </message>
@@ -129,47 +130,49 @@
 <context>
     <name>ResultView</name>
     <message>
-        <location filename="../app/view/resultview.cpp" line="137"/>
+        <location filename="../app/view/resultview.cpp" line="104"/>
         <source>Reboot now</source>
         <translation>ལམ་སེང་བསྐྱར་སློང་བྱེད།</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="120"/>
-        <source>Done</source>
-        <translation>གྲུབ་ཟིན། </translation>
-    </message>
-    <message>
-        <location filename="../app/view/resultview.cpp" line="68"/>
+        <location filename="../app/view/resultview.cpp" line="56"/>
         <source>Successful</source>
         <translation>བཟོ་ཐུབ་སོང་།</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="217"/>
+        <location filename="../app/view/resultview.cpp" line="95"/>
+        <source>Done</source>
+        <comment>button</comment>
+        <translation>གྲུབ་ཟིན། </translation>
+    </message>
+    <message>
+        <location filename="../app/view/resultview.cpp" line="169"/>
         <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
         <translation>གནད་དོན་ལྡོག་སྐྱེལ་བྱེད་སྐབས་རང་འགུལ་ངང་ནོར་འཁྲུལ་ཉིན་ཐོ་སྐྱེལ་འཇོག་བྱེད་སྲིད། ང་ཚོའི་ཡར་རྒྱས་དང་སྐུ་ཉིད་ཀྱི་ལྡོག་སྐྱེལ་དང་རྒྱབ་སྐྱོར་བྲལ་ཐབས་མེད།</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="218"/>
+        <location filename="../app/view/resultview.cpp" line="170"/>
         <source>Submit Feedback</source>
         <translation>ལྡོག་སྐྱེལ་སྤྲོད་པ།</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="241"/>
+        <location filename="../app/view/resultview.cpp" line="193"/>
         <source>After-Sale Services</source>
         <translation>བཙོངས་རྗེས་ཞབས་ཞུ།</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="254"/>
+        <location filename="../app/view/resultview.cpp" line="206"/>
         <source>Close</source>
-        <translation>སྒོ་བརྒྱབ།</translation>
+        <comment>button</comment>
+        <translation>ཁ་རྒྱག</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="262"/>
+        <location filename="../app/view/resultview.cpp" line="214"/>
         <source>Sorry, process failed</source>
         <translation>བཟོ་མི་ཐུབ་པས། དགོངས་པ་མ་ཚོམ།</translation>
     </message>
     <message>
-        <location filename="../app/view/resultview.cpp" line="263"/>
+        <location filename="../app/view/resultview.cpp" line="215"/>
         <source>Process failed</source>
         <translation>བཟོ་མི་ཐུབ།</translation>
     </message>
@@ -185,59 +188,68 @@
 <context>
     <name>UsbSelectView</name>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="95"/>
+        <location filename="../app/view/usbselectview.cpp" line="92"/>
         <source>Select a partition</source>
         <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
     </message>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="122"/>
+        <location filename="../app/view/usbselectview.cpp" line="117"/>
         <source>Format the partition</source>
         <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
     </message>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="171"/>
+        <location filename="../app/view/usbselectview.cpp" line="170"/>
         <source>Start</source>
         <translation>བཟོ་འགོ་ཚུགས་པ།</translation>
     </message>
-    <message>
-        <location filename="../app/view/usbselectview.cpp" line="175"/>
-        <source>Back</source>
-        <translation>ཕྱིར་ལོག</translation>
-    </message>
     <message>
         <location filename="../app/view/usbselectview.cpp" line="231"/>
         <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
         <translation>རྣམ་གཞག་ཏུ་སྒྱུར་བ་འདིས་དབྱེ་ཁུལ་ཐོག་གི་གཞི་གྲངས་ཚང་མ་བསུབ་སྲིད། འོན་ཀྱང་བཟོ་ཚད་མཐོ་རུ་གཏོང་སྲིད་པས། གཏན་འཁེལ་རྗེས་མུ་མཐུད་བྱེད། </translation>
     </message>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="368"/>
+        <location filename="../app/view/usbselectview.cpp" line="377"/>
+        <location filename="../app/view/usbselectview.cpp" line="388"/>
+        <source>OK</source>
+        <comment>button</comment>
+        <translation>གཏན་ཁེལ།</translation>
+    </message>
+    <message>
+        <location filename="../app/view/usbselectview.cpp" line="380"/>
+        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <location filename="../app/view/usbselectview.cpp" line="384"/>
+        <source>Cancel</source>
+        <comment>button</comment>
+        <translation>ཕྱིར་འཐེན།</translation>
+    </message>
+    <message>
+        <location filename="../app/view/usbselectview.cpp" line="391"/>
         <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
         <translation>རྣམ་གཞག་ཏུ་སྒྱུར་བ་འདིས་ཁུལ་དེའི་གཞི་གྲངས་ཚང་མ་བརླག་སྲིད་པས། གྲབས་ཉར་བྱས་རྗེས་མུ་མཐུད་བེད་སྤྱོད་བྱེད། </translation>
     </message>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="402"/>
+        <location filename="../app/view/usbselectview.cpp" line="407"/>
         <source>Disk Format Error: Please format the partition with FAT32</source>
         <translation>སྡུད་སྡེར་གྱི་རྣམ་གཞག་ནོར་བས། FAT32རྣམ་གཞག་བེད་སྤྱད་བྱས་ཏེ་ཡང་བསྐྱར་རྣམ་གཞག་ཏུ་སྒྱུར་ནས་ཁུལ་དབྱེ་བ།</translation>
     </message>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="156"/>
+        <location filename="../app/view/usbselectview.cpp" line="153"/>
         <source>No disk available</source>
         <translation>སྤྱོད་རུང་བའི་སྡུད་སྡེར་རྙེད་མ་བྱུང་།</translation>
     </message>
     <message>
-        <location filename="../app/view/usbselectview.cpp" line="365"/>
+        <location filename="../app/view/usbselectview.cpp" line="174"/>
+        <source>Back</source>
+        <comment>button</comment>
+        <translation>ཕྱིར་ལོག</translation>
+    </message>
+    <message>
+        <location filename="../app/view/usbselectview.cpp" line="358"/>
         <source>Format Partition</source>
         <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
     </message>
-    <message>
-        <location filename="../app/view/usbselectview.cpp" line="372"/>
-        <source>Cancel</source>
-        <translation>ཕྱིར་འཐེན།</translation>
-    </message>
-    <message>
-        <location filename="../app/view/usbselectview.cpp" line="374"/>
-        <source>OK</source>
-        <translation>གཏན་ཁེལ།</translation>
-    </message>
 </context>
 </TS>
\ No newline at end of file
